"use strict";

require("core-js/modules/es.regexp.exec.js");

require("core-js/modules/es.string.split.js");

require("core-js/modules/es.object.assign.js");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/web.dom-collections.iterator.js");

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _ChatShellModule = _interopRequireDefault(require("./ChatShell.module.scss"));

var _ChatListShell = _interopRequireDefault(require("../ChatListShell/ChatListShell"));

var _ConversationShell = _interopRequireDefault(require("../ConversationShell/ConversationShell"));

var _chatListOptions = require("../../sampleData/chatListOptions");

var _client = require("@apollo/client");

var _error = require("@apollo/client/link/error");

var _ws = require("@apollo/client/link/ws");

var _utilities = require("@apollo/client/utilities");

var _reactRouterDom = require("react-router-dom");

var _usePreviousState = _interopRequireDefault(require("../../_helpers/usePreviousState"));

const _excluded = ["connectionUri", "subscriptionUri", "chatApiUrl", "query"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

const ChatShell = _ref => {
  let {
    connectionUri,
    subscriptionUri,
    chatApiUrl,
    query
  } = _ref,
      rest = _objectWithoutProperties(_ref, _excluded);

  const [queryMessagesBody, setQueryMessagesBody] = _react.default.useState(null);

  const prevQueryRef = (0, _usePreviousState.default)(query);

  _react.default.useEffect(() => {
    if ((query === null || query === void 0 ? void 0 : query.parameter.length) === 0 || (prevQueryRef === null || prevQueryRef === void 0 ? void 0 : prevQueryRef.parameter) !== query.parameter) {
      setQueryMessagesBody(null);
    }
  }, [query, prevQueryRef]);

  const errorLink = (0, _error.onError)(_ref2 => {
    let {
      graphqlErrors,
      networkError
    } = _ref2;

    if (graphqlErrors) {
      graphqlErrors.map(_ref3 => {
        let {
          message,
          location,
          path
        } = _ref3;
        return alert("Graphql error ".concat(message));
      });
    }
  });
  const httpLink = (0, _client.from)([errorLink, new _client.HttpLink({
    uri: connectionUri
  })]);
  const wsLink = process.browser ? new _ws.WebSocketLink({
    uri: subscriptionUri,
    options: {
      reconnect: true,
      lazy: true
    }
  }) : null;
  const splitLink = process.browser ? (0, _client.split)(_ref4 => {
    let {
      query
    } = _ref4;
    const definition = (0, _utilities.getMainDefinition)(query);
    return definition.kind === 'OperationDefinition' && definition.operation === 'subscription';
  }, wsLink, httpLink) : httpLink;
  const client = new _client.ApolloClient({
    cache: new _client.InMemoryCache(),
    link: splitLink
  });
  const [isUsername, setIsUsername] = (0, _react.useState)(false);

  const handleSetIsUsername = val => {
    if (val) {
      setIsUsername(true);
    } else {
      setIsUsername(false);
    }
  };

  const handleQueryMessage = messageBody => {
    setQueryMessagesBody(messageBody);
  };

  return /*#__PURE__*/_react.default.createElement(_client.ApolloProvider, {
    client: client
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _ChatShellModule.default.ChatShell
  }, /*#__PURE__*/_react.default.createElement(_ChatListShell.default, _extends({
    options: _chatListOptions.chatListOptions,
    isUsername: isUsername,
    query: query,
    setQueryMessagesBody: handleQueryMessage
  }, rest)), /*#__PURE__*/_react.default.createElement(_ConversationShell.default, {
    chatApiUrl: chatApiUrl,
    queryMessagesBody: queryMessagesBody,
    handleSetIsUsername: handleSetIsUsername
  })));
};

ChatShell.propTypes = {
  query: _propTypes.default.shape({
    parameter: _propTypes.default.string
  }),
  resetChatList: _propTypes.default.func
};
ChatShell.defaultProps = {
  query: {
    parameter: ''
  },
  resetChatList: () => console.log('This function will reset the ChatListSheel to its default state')
};

var _default = /*#__PURE__*/_react.default.memo(ChatShell);

exports.default = _default;