import React, { useEffect, useState } from 'react';
import styles from './ChatListShell.module.scss';
import { Select } from 'antd';
import { ArrowLeftOutlined } from '@ant-design/icons';
import PropTypes from 'prop-types';
import ChatList from '../ChatList/ChatList';
import SearchList from '../SearchList/SearchList';
import { Tabs } from 'antd';
import { LOAD_USERS } from '../../GraphQL/Queries';
import { useSubscription } from '@apollo/client';

const { TabPane } = Tabs;
const { Option } = Select;

const ChatListShell = ({ options,query,resetChatList ,isUsername, setQueryMessagesBody}) => {

  const [chatOptions, setChatOptions] = useState([])
  const [selectedOption, setSelectedOption] = useState("allchats")
  const { data } = useSubscription(LOAD_USERS);

  useEffect(() => {
    setChatOptions(options);
  }, [options]);

  const handleChatOptions = value => {
    setSelectedOption(value);
  };

  return (
    <div
      className={
        isUsername
          ? `${styles.ChatListShell__hide + ' ' + styles.ChatListShell}`
          : styles.ChatListShell
      }
    >
        <div className={styles.ChatListShell__bar}>
          {query.parameter.length === 0 ? (
            <Select
              defaultValue="allchats"
              bordered={false}
              value={selectedOption}
              data-testid="ChatListShell-select"
              onChange={handleChatOptions}
            >
              {chatOptions?.map((op) => {
                return (
                  <Option key={op.id} value={op.value}>
                    {op.label}
                  </Option>
                );
              })}
            </Select>
          ) : (
            <div>
              <ArrowLeftOutlined onClick={resetChatList} />
              <span style={{ marginLeft: '10px', fontWeight: '600' }}>
                Search
              </span>
            </div>
          )}
        </div>
      {query?.parameter.length === 0 ? (
        <div
          className={styles.ChatListShell__mobilebar}
          data-testid="ChatListShell-mobilebar"
        >
          <Tabs
            defaultActiveKey="allchats"
            onChange={handleChatOptions}
            centered
          >
            {chatOptions?.map(op => {
              return <TabPane tab={op.label} key={op.value}></TabPane>;
            })}
          </Tabs>
        </div>
      ) : null}
      {query?.parameter.length === 0 ? (
        selectedOption === 'allchats' ? (
          <ChatList data={data} />
        ) : (
          <div></div>
        )
      ) : (
        <SearchList query={query} setQueryMessagesBody={setQueryMessagesBody} />
      )}
    </div>
  );
};

export default ChatListShell;

ChatListShell.propTypes = {
  query: PropTypes.shape({
    parameter: PropTypes.string,
  }),
  resetChatList: PropTypes.func,
};

ChatListShell.defaultProps = {
  query: { parameter: '' },
  resetChatList: () =>
    console.log(
      'This function will reset the ChatListSheel to its default state'
    ),
};
