import React from 'react';
import ReactDOM from 'react-dom';
import ConversationContainer from './ConversationContainer';
import { MockedProvider } from '@apollo/client/testing';
import { LOAD_MESSAGES, LOAD_USERS } from '../../GraphQL/Queries';
import {
  render,
  screen,
  getByText,
  waitFor,
  getByTestId,
  fireEvent,
} from '@testing-library/react';
import renderer from 'react-test-renderer';

const mocks = [];

const comp = (
  <MockedProvider mocks={mocks}>
    <ConversationContainer />
  </MockedProvider>
);

describe('rendring of components', () => {
  it('It should mount', () => {
    const div = document.createElement('div');
    ReactDOM.render(comp, div);
    ReactDOM.unmountComponentAtNode(div);
  });
  it('Input field should be rendered', () => {
    const { getByPlaceholderText } = render(comp);
    expect(getByPlaceholderText('Input placeholder')).toBeInTheDocument();
  });
});

describe('chatitem selection behaviour', () => {
  it('Input should change when message is typed ', () => {
    const { queryByTestId, getByPlaceholderText, getByText } = render(comp);
    fireEvent.change(getByPlaceholderText('Input placeholder'), {
      target: { value: 'new value' },
    });
    expect(getByPlaceholderText('Input placeholder')).toHaveValue('new value');
  });
});
