import React, { useEffect } from 'react';
import styles from './ConversationShell.module.scss';
import sample from '../../assets/sample.png';
import { Spin, Tabs } from 'antd';
import ConversationContainer from '../ConversationContainer/ConversationContainer';
import { useSubscription } from '@apollo/client';
import { LOAD_MESSAGES } from '../../GraphQL/Queries';
import { ArrowLeftOutlined, SearchOutlined, MoreOutlined } from '@ant-design/icons';
import { useParams } from 'react-router-dom';
import { getQueryMessages } from '../../api/api';

const { TabPane } = Tabs;

const ConversationShell = ({ chatApiUrl, queryMessagesBody, handleSetIsUsername }) => {
  const { username } = useParams()
  const { data, refetch, loading } = useSubscription(LOAD_MESSAGES, {
    variables: {
      "leadId": username
    }
  });
  const [queryMessages, setQueryMessage] = React.useState([]);
  const tabStyles = { paddingTop: '20px' };

  useEffect(() => {
    handleSetIsUsername(username)
  }, [username])

  useEffect(() => {
    setQueryMessage([]);
    const fetchQueryMessages = async () => {
      if (
        (queryMessagesBody !== null) &
        (queryMessagesBody?.threadId !== null)
      ) {
        const { data } = await getQueryMessages(
          'https://backend.dgraph.smarter.codes',
          queryMessagesBody
        );
        setQueryMessage(data.messages);
      }
    };
    fetchQueryMessages();
  }, [queryMessagesBody]);


  function callback(key) {
    console.log(key);
  }

  return (
    <div className={styles.ConversationShell}>
      {!username ? <div className={styles.ConversationShell__bar}>
        <span data-testid="selectcontact" className={styles.ConversationShell__bar__selectcontact}>Select a contact</span>
      </div> :
        <>
          <div className={styles.ConversationShell__bar}>
            <div className={styles.ConversationShell__bar__imgcontainer}>
              <img src={sample} alt={data?.getHC_Lead?.username || ""}></img>
              <div className={styles.ConversationShell__bar__imgcontainer__status_circle}>
              </div>
            </div>
            <h6 className={styles.ConversationShell__bar__name}>
              {data?.getHC_Lead?.username}
            </h6>
            <div className={styles.ConversationShell__bar__panels}>
              <Tabs defaultActiveKey="1" onChange={callback} tabBarStyle={tabStyles}>
                <TabPane tab="Chat" key="1">
                </TabPane>
                <TabPane tab="Files" key="2">
                </TabPane>
                <TabPane tab="Starred Messages" key="3">
                </TabPane>
              </Tabs>
            </div>
          </div>
          <div className={styles.ConversationShell__mobilebar}>
            <ArrowLeftOutlined className={styles.ConversationShell__mobilebar__icon} onClick={() => window.history.back()} />
            <div className={styles.ConversationShell__mobilebar__imgcontainer}>
              <img src={sample} alt={data?.getHC_Lead?.username || ""}></img>
              <div className={styles.ConversationShell__mobilebar__imgcontainer__status_circle}>
              </div>
              <h6 className={styles.ConversationShell__mobilebar__name}>
                {data?.getHC_Lead?.username}
              </h6>
              <SearchOutlined
                className={styles.ConversationShell__mobilebar__icon}
              />
              <MoreOutlined
                className={styles.ConversationShell__mobilebar__icon}
              />
            </div>
            <h6 className={styles.ConversationShell__mobilebar__name}>
              {data?.getHC_Lead?.username}
            </h6>
            <SearchOutlined className={styles.ConversationShell__mobilebar__icon} />
            <MoreOutlined className={styles.ConversationShell__mobilebar__icon} />
          </div>
        </>
      }
      {loading ? <Spin size="large" className={styles.ConversationShell__loading} /> : <ConversationContainer user={data} selectedId={username} refetch={refetch} chatApiUrl={chatApiUrl} queryMessages={queryMessages} queryMessagesBody={queryMessagesBody} />}
    </div>
  );
};

export default ConversationShell;
