import React from 'react';
import ReactDOM from 'react-dom';
import ConversationShell from './ConversationShell';
import { MockedProvider } from '@apollo/client/testing';
import { LOAD_MESSAGES } from "../../GraphQL/Queries";
import { render, waitFor } from '@testing-library/react';
import ReactRouter from 'react-router-dom'

const mockedUsedNavigate = jest.fn();

jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedUsedNavigate,
  useParams: () => ({
    username: 'X2034S',
  }),
}));


const mocks = [];

const comp = <MockedProvider mocks={mocks}>
  <ConversationShell handleSetIsUsername={() => { }} />
</MockedProvider>

describe('rendring of components', () => {
  it('It should mount', () => {
    const div = document.createElement('div');
    ReactDOM.render(comp, div);
    ReactDOM.unmountComponentAtNode(div);
  });
});

describe('data from query', () => {
  it('It should mount with data', async () => {
    jest.spyOn(ReactRouter, 'useParams').mockReturnValue({ username: '0x2725' });
    const loadusersmock = {
      request: {
        query: LOAD_MESSAGES,
        variables: {
          leadId: '0x2725',
        },
      },
      result: {
        data: {
          getHC_Lead: {
            username: 'Sahil Thakur',
            threads: [
              {
                id: '0x2724',
                messages: [
                  {
                    from: 'whatsapp:+918988413260',
                    to: 'whatsapp:+14155238886',
                    timestamp: '1637295513344',
                    body: 'Sending first message',
                    type: '',
                    __typename: 'Message',
                  },
                  {
                    from: 'whatsapp:+918988413260',
                    to: 'whatsapp:+14155238886',
                    timestamp: '1637295528041',
                    body: 'Second message from me',
                    type: '',
                    __typename: 'Message',
                  },
                ],
                __typename: 'Thread',
              },
            ],
            __typename: 'HC_Lead',
          },
        },
      },
    };
    let el = <MockedProvider mocks={[loadusersmock]}>
      <ConversationShell selectedId={"0x2725"} handleSetIsUsername={() => { }} />
    </MockedProvider>
    await new Promise(resolve => setTimeout(resolve, 1000)); // wait for response
    const { container, getAllByText } = render(el)
    await waitFor(() => expect(getAllByText("Sahil Thakur")[0]).toBeInTheDocument())
  })
}
)



describe('tabs should render', () => {
  it('Files option should render if there is a selected id', async () => {
    jest.spyOn(ReactRouter, 'useParams').mockReturnValue({ username: 'X2012' });
    const { container, getByText } = render(<MockedProvider mocks={mocks}>
      <ConversationShell selectedId="x" handleSetIsUsername={() => { }} />
    </MockedProvider>)
    await waitFor(() => expect(getByText("Files")).toBeInTheDocument())
  })
}
)
describe(('rendering of items when no chat is selected'), () => {
  it('should show select contact if there is NO selected id', async () => {
    jest.spyOn(ReactRouter, 'useParams').mockReturnValue({ username: null });
    const { container, getByTestId } = render(<MockedProvider mocks={mocks}>
      <ConversationShell handleSetIsUsername={() => { }} />
    </MockedProvider>)
    await waitFor(() => expect(getByTestId("selectcontact")).toBeInTheDocument())
  })
}
)
