import React from 'react';
import ReactDOM from 'react-dom';
import Message from './Message';
import { MockedProvider } from '@apollo/client/testing';
import { LOAD_MESSAGES, LOAD_USERS } from "../../GraphQL/Queries";
import { render, screen, getByText, waitFor, getByTestId, fireEvent } from '@testing-library/react';
import renderer from "react-test-renderer";


const mocks = [];

const comp = <MockedProvider mocks={mocks}>
  <Message />
</MockedProvider>

describe(('rendring of components'), () => {
  it('It should mount', () => {
    const div = document.createElement('div');
    ReactDOM.render(comp, div);
    ReactDOM.unmountComponentAtNode(div);
  })
}
)

describe(('data from query'), () => {
  it('message is rendered', async () => {
    let samplemsg = {
      from: "whatsapp:+918988413260",
      to: "whatsapp:+14155238886",
      timestamp: "1637295513344",
      body: "Sending first message",
      __typename: "Message"
    }
    let el = <MockedProvider mocks={[]}>
      <Message message={samplemsg} />
    </MockedProvider>
    await new Promise(resolve => setTimeout(resolve, 1000)); // wait for response
    const { container, getByText } = render(el)
    await waitFor(() => expect(getByText("Sending first message")).toBeInTheDocument())
  })

  it('if message is ours then color is blue', async () => {
    let samplemsg = {
      from: "whatsapp:+918988413260",
      to: "whatsapp:+14155238886",
      timestamp: "1637295513344",
      body: "Sending first message",
      __typename: "Message"
    }
    let el = <MockedProvider mocks={[]}>
      <Message message={samplemsg} isMyMessage={true} />
    </MockedProvider>
    await new Promise(resolve => setTimeout(resolve, 1000)); // wait for response
    const { container, getByText } = render(el)
    expect(container.firstChild.firstChild).toHaveClass("you-message")
  })

  it('if message is theirs then color is not blue', async () => {
    let samplemsg = {
      from: "whatsapp:+918988413260",
      to: "whatsapp:+14155238886",
      timestamp: "1637295513344",
      body: "Sending first message",
      __typename: "Message"
    }
    let el = <MockedProvider mocks={[]}>
      <Message message={samplemsg} isMyMessage={false} />
    </MockedProvider>
    await new Promise(resolve => setTimeout(resolve, 1000)); // wait for response
    const { container, getByText } = render(el)
    expect(container.firstChild.firstChild).toHaveClass("other-message")
  })
}
)
