import React, { useEffect, useState } from 'react';
import { useQuery } from '@apollo/client';
import { Tabs } from 'antd';
import { DownOutlined } from '@ant-design/icons';
import PropTypes from 'prop-types';
import styles from './SearchList.module.scss';
import MessageItem from '../MessageItem/MessageItem';
import { LOAD_SEARCH_LIST } from '../../GraphQL/Queries';

const SearchList = ({ query, setQueryMessagesBody }) => {
  const { data } = useQuery(LOAD_SEARCH_LIST, {
    variables: {
      filter: {
        body: {
          anyofterms: query.parameter,
        },
      },
    },
  });
  const [queryMessages, setQueryMessages] = useState([]);
  const [chosen, setChosen] = useState(null);
  const { TabPane } = Tabs;
  const tabStyles = { padding: '20px 0px 0px 20px' };

  useEffect(() => {
    if (data) {
      setQueryMessages(data.queryMessage);
    }
  }, [data]);

  const handleMessageSelect = (user) => {
    const threadId = user.thread !== null ? user.thread.id : user.thread;
    setQueryMessagesBody({
      threadId,
      messageId: user.id,
    });
  };

  return (
    <div className={styles.SearchList}>
      <div className={styles.SearchList__bar__panels}>
        <Tabs
          defaultActiveKey="1"
          tabBarStyle={tabStyles}
        >
          <TabPane tab="Messages" key="1"></TabPane>
          <TabPane tab="Contacts" key="2"></TabPane>
          <TabPane tab="Files" key="3"></TabPane>
        </Tabs>
      </div>
      <div className={styles.SearchList__bar__settings}>
        <span className={styles.SearchList__bar__settings__options}>
          Filter{' '}
          <DownOutlined className={styles.SearchList__icons__downarrow} />
        </span>
        <span className={styles.SearchList__bar__settings__options}>
          Sort <DownOutlined className={styles.SearchList__icons__downarrow} />
        </span>
      </div>
      <div className={styles.SearchList__query_messages_container}>
        <div
          className={styles.SearchList__query_messages_container__inner_area}
        >
          {queryMessages.length ? (
            queryMessages.map((user, index) => {
              return (
                <div key={index} onClick={() => handleMessageSelect(user)}>
                  <MessageItem
                    data-testid="ChatItem"
                    key={user.id}
                    user={user}
                    query={query}
                    active={user.id === chosen}
                    handleActiveMessage={() => setChosen(user.id)}
                  />
                </div>
              );
            })
          ) : (
            <div className={styles.SearchList__not_found_msg}>No matches</div>
          )}
        </div>
      </div>
    </div>
  );
};

SearchList.propTypes = {
  query: PropTypes.shape({
    parameter: PropTypes.string,
  }),
};

SearchList.defaultProps = {
  query: { parameter: '' },
};

export default SearchList;
